@@ -7,7 +7,7 @@ package App::SeismicUnixGui::sunix::plot::suximage;
 SUXIMAGE also inherits parameters from XIMAGE (See below)
 
  PERL PROGRAM NAME:  SUXIMAGE - X-windows IMAGE plot of a segy data set	                
- AUTHOR: Juan Lorenzo
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
